## START: Set by rpmautospec
## (rpmautospec version 0.3.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# force out-of-tree build for spec compatibility with older releases
%undefine __cmake_in_source_build

%global forgeurl https://github.com/Brewtarget/brewtarget

%global _description %{expand:
Brewtarget is an open source beer recipe creation tool. It automatically
calculates color, bitterness, and other parameters for you while you drag and
drop ingredients into the recipe. Brewtarget also has many other tools such as
priming sugar calculators, OG correction help, and a unique mash designing tool.
It also can export and import recipes in BeerXML.}

Name:           brewtarget
Version:        3.0.11
Release:        %{autorelease}
Summary:        An open source beer recipe creation tool 🍺
%forgemeta
# BSD-2-Clause: cmake/modules/FindPhonon.cmake
# WTFPL: images/flag* images/bubbles.svg images/convert.svg images/grain2glass.svg
# CC-BY-SA-3.0 OR LGPL-3.0-only: images/edit-copy.png images/document-print-preview.png
#     images/merge.png images/preferences-other.png images/printer.png
#     images/server-database.png images/kbruch.png images/help-contents.png
# LGPL-2.1-only: images/backup.png
License:    GPL-3.0-or-later AND BSD-2-Clause AND WTFPL AND (CC-BY-SA-3.0 OR LGPL-3.0-only) AND LGPL-2.1-only
URL:        %{forgeurl}
Source0:    %{forgesource}
Patch:      fix_boost_requirements.patch

BuildRequires:  gcc-c++
BuildRequires:  qt5-qtbase-devel, qt5-qtwebkit-devel, qt5-qtsvg-devel
BuildRequires:  qt5-qtmultimedia-devel, qt5-linguist
BuildRequires:  boost-devel, xerces-c-devel, xalan-c-devel
BuildRequires:  desktop-file-utils
BuildRequires:  meson
BuildRequires:  git-core
BuildRequires:  pandoc
BuildRequires:  xorg-x11-server-Xvfb
Requires:       sqlite

# Stop building for i686
# See: https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch:    %{ix86}

%description %_description

%prep
%autosetup -n %{name}-%{version} -S git
# Crude way of disabling testLogRotation
sed -i -e '/testLogRotation/d' meson.build


%build
%meson
%meson_build


%install
%meson_install


%check
# Run in minimal graphical env (thanks @ankursinha).
# We need to pass the Meson test command as a script to xvfb-run.
cat > mesontest.sh << EOF
#!/bin/sh
mkdir %{_builddir}/%{name}-%{version}/brewtarget-test
export TMPDIR="%{_builddir}/%{name}-%{version}/brewtarget-test"
%meson_test --verbose
EOF
chmod a+x ./mesontest.sh
xvfb-run ./mesontest.sh
desktop-file-validate %buildroot%{_datadir}/applications/%{name}.desktop

%files
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man1/brewtarget*
%{_docdir}/%{name}/*.markdown
%{_docdir}/%{name}/copyright
%doc doc/manual-en.pdf
%license COPYRIGHT COPYING.GPLv3 COPYING.WTFPL

%changelog
* Sun Feb 04 2024 Packit <hello@packit.dev> - 3.0.11-1
- [packit] 3.0.11 upstream release
- Resolves rhbz#2262692

* Tue Jan 23 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.10-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jan 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Jan 03 2024 Sandro <devel@penguinpee.nl> - 3.0.10-2
- Stop building for i686

* Sun Dec 31 2023 Packit <hello@packit.dev> - 3.0.10-1
- [packit] 3.0.10 upstream release
- Resolves rhbz#2256264

* Sun Oct 29 2023 Sandro <devel@penguinpee.nl> - 3.0.9-3
- Add Packit config

* Tue Sep 05 2023 Sandro <devel@penguinpee.nl> - 3.0.9-2
- Make testing more failsafe
- Provide temp dir for log files
- Use here script for better readability

* Mon Sep 04 2023 Sandro <devel@penguinpee.nl> - 3.0.9-1
- Update to 3.0.9 (RHBZ#2175532)
- Switch to Meson build
- Run tests in virtual graphical env
- General spec file housekeeping

* Wed Jul 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Mon Feb 13 2023 Sandro <devel@penguinpee.nl> - 3.0.6-1
- Update to 3.0.6 (RHBZ#2167997)
- Add missing changelog
- Use %autorelease

* Mon Jan 16 2023 Sandro <devel@penguinpee.nl> - 3.0.5-1
- Update to 3.0.5 (RHBZ#2156207)

* Tue Nov 29 2022 Sandro <devel@penguinpee.nl> - 3.0.4-1
- Update to 3.0.4 (RHBZ#2149053)
- Fix desktop file location

* Wed Nov 23 2022 Sandro <devel@penguinpee.nl> - 3.0.3-4
- Drop definition of tag

* Wed Nov 23 2022 Sandro <devel@penguinpee.nl> - 3.0.3-3
- Ignore tab to space conversion

* Wed Nov 23 2022 Sandro <devel@penguinpee.nl> - 3.0.3-2
- Convert tabs to spaces

* Sat Nov 12 2022 Sandro <devel@penguinpee.nl> - 3.0.3-1
- Update to 3.0.2 (RHBZ#2140886)
- SPDX migration

* Fri Oct 28 2022 Sandro <devel@penguinpee.nl> - 3.0.2-1
- Update to 3.0.2 (RHBZ#2134223)
- Update dependencies
- Update and clarify licenses
- Use %forgemeta and %autochangelog
- Replace BR cmake with gcc-c++

* Wed Jul 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jan 19 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-16
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Sep 16 2019 Kevin Fenzi <kevin@scrye.com> - 2.1.0-13
- Fix FTBFS bug #1734987

* Wed Jul 24 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 2.1.0-2
- Rebuilt for GCC 5 C++11 ABI change

* Wed Nov 12 2014 Pete Travis <me@petetravis.com> - 2.1.0-2
- Update to upstream 2.1.0
- Adds inventory tracking for ingredients
- Folders for organizing recipes
- Recipe parameter sliders
- Various bugfixes, ref http://www.brewtarget.org/changelog.html

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Feb 17 2014 Pete Travis <immanetize@fedoraproject.org> - 2.0.2-1
- Update to version 2.0.2
- Mostly a bugfix release, see http://www.brewtarget.org/changelog.html

* Sat Aug 03 2013 Pete Travis <immanetize@fedoraproject.org> - 2.0.1-2
- Update to version 2.0.1
- Removing patches where integrated upstream
- patch for unversioned docdirs on Fedora releases >= 20

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sun Nov 18 2012 Pete Travis <immanetize@fedoraproject.org> 1.2.3-4
- Fixing permissions on manpage

* Sat Nov 17 2012 Pete Travis <immanetize@fedoraproject.org> 1.2.5-3
- Including bundled manpage, updating SPEC

* Fri Nov 16 2012 Pete Travis <immanetize@fedoraproject.org> 1.2.5-2
- Changes to SPEC file per packaging guidelines.

* Mon Nov 12 2012 Pete Travis <immanetize@fedoraproject.org> 1.2.5-1
- Initial build of 1.2.5 release

* Mon Nov 12 2012 Pete Travis <immanetize@fedoraproject.org> 1.2.5-1
- Added patch to correct .desktop file

* Mon Nov 12 2012 Pete Travis <immanetize@fedoraproject.org> 1.2.5-1
- Added patch to install documentation to appropriate directory

* Mon Nov 12 2012 Pete Travis <immanetize@fedoraproject.org> 1.2.5-1
- Patching to warn if no documentation instead of exit.

